module.exports = defineTest({
	description: 'handles setters shadowed by computed setters'
});
